<?php

	defined( 'ABSPATH' ) || exit;

	add_action('widgets_init', 'enovathemes_addons_register_car_filter_widget');
	function enovathemes_addons_register_car_filter_widget(){
		register_widget( 'Enovathemes_Addons_WP_Widget_Car_Filter' );
	}

	class Enovathemes_Addons_WP_Widget_Car_Filter extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'car_filter_widget',
				esc_html__('* Filter', 'enovathemes-addons'),
				array( 'description' => esc_html__('Filter products by make/model/trim or WooCommerce global attributes', 'enovathemes-addons'))
			);
		}

		public function widget( $args, $instance) {

			wp_enqueue_script('widget-car-filter');

			extract($args);

			$title            = apply_filters( 'widget_title', $instance['title'] );
			$type             = isset($instance['type']) ? esc_attr($instance['type']) : 'vertical';
			$vin              = isset($instance['vin']) ? esc_attr($instance['vin']) : 'false';
			$use_attrs        = isset($instance['use_attrs']) ? esc_attr($instance['use_attrs']) : 'false';
			$hierarchy        = isset($instance['hierarchy']) ? esc_attr($instance['hierarchy']) : 'false';
			$atts             = isset($instance['atts']) ? esc_attr($instance['atts']) : '';
			$depth            = isset($instance['depth']) ? esc_attr($instance['depth']) : 'trim';
			$description      = isset($instance['description']) ? htmlentities($instance['description']) : '';
			$description_back = isset($instance['description_back']) ? esc_attr($instance['description_back']) : '#ffc600';
			$filter_back      = isset($instance['filter_back']) ? esc_attr($instance['filter_back']) : '#ffd800';
			$filter_color     = isset($instance['filter_color']) ? esc_attr($instance['filter_color']) : '#000000';

			$button_back       = isset($instance['button_back']) ? esc_attr($instance['button_back']) : '#d52b27';
			$button_back_hover = isset($instance['button_back_hover']) ? esc_attr($instance['button_back_hover']) : '#000000';

			$button_color       = isset($instance['button_color']) ? esc_attr($instance['button_color']) : '#ffffff';
			$button_color_hover = isset($instance['button_color_hover']) ? esc_attr($instance['button_color_hover']) : '#ffffff';

			wp_enqueue_style('widget-car-filter-styles');

			$dynamic_css = "";
			$id          = isset($args['widget_id']) ? $args['widget_id'] : 'car_filter_widget-1';

			if (!empty($description_back)) {
				$dynamic_css .='#'.$id.' .car-filter-description{
					background-color: '.$description_back.';
				}';
			}

			if (!empty($filter_back)) {
				$dynamic_css .='#'.$id.' .et-car-filter, #'.$id.' .et-car-filter .vertical-vin-text{
					background-color: '.$filter_back.';
				}';
			}

			if (!empty($filter_color)) {
				$dynamic_css .='#'.$id.' .et-car-filter{
					color: '.$filter_color.';
				}';

				$dynamic_css .='#'.$id.' .car-filter.vertical .vin-label:before{
					background-color: '.mobimax_enovathemes_hex_to_rgba($filter_color,0.2).';
				}';
			}

			if (!empty($button_back)) {
				$dynamic_css .='#'.$id.' .car-filter-button{
					background-color: '.$button_back.';
				}';
			}

			if (!empty($button_back_hover)) {
				$dynamic_css .='#'.$id.' .car-filter-button:hover{
					background-color: '.$button_back_hover.';
				}';
			}

			if (!empty($button_color)) {
				$dynamic_css .='#'.$id.' .car-filter-button{
					color: '.$button_color.';
				}';
			}

			if (!empty($button_color_hover)) {
				$dynamic_css .='#'.$id.' .car-filter-button:hover{
					color: '.$button_color_hover.';
				}';
			}

			$dynamic_css = mobimax_enovathemes_minify_css($dynamic_css);
			wp_add_inline_style( 'widget-car-filter-styles', $dynamic_css );

			echo $before_widget;

				if ( ! empty( $title ) ){echo $before_title . $title . $after_title;}

				$class = array();

			    $class[] = 'depth-'.$depth;
			    $class[] = $type;

			    if ($vin == "true") {
			    	$class[] = 'vin-'.$vin;
			    }

			    $shop_link = (function_exists('wc_get_page_id')) ? get_permalink( wc_get_page_id( 'shop' ) ) : '';

			    if ('' === get_option( 'permalink_structure' )) {
			    	$shop_link = get_home_url().'?post_type=product';
			    }

			    if ($use_attrs == "true" && !empty($atts)) {

			    	$vin = 'false';

			    	$attibutes  = enovathemes_addons_build_filter_attributes();

			    	$class[] = 'hierarchy-'.$hierarchy;
			    	$class[] = 'attributes-true';


					$atts_ids = array();
					$cat      = false;

					$atts = explode("|", $atts);

					foreach ($atts as $att) {
						$att_array = explode(',', $att);
						if ($att_array[0] != 'cat') {
							array_push($atts_ids, $att_array[0]);
						} else {
							$cat = true;
						}
					}

					$attibutes_filter = array();

					foreach ($atts_ids as $id) {
						if (array_key_exists($id, $attibutes)) {
							array_push($attibutes_filter, $attibutes[$id]);
						}
					}


			    } else {

					$filter = enovathemes_addons_build_filter();

					if (!is_wp_error( $filter ) ) {
						$makes  = $filter['makes'];

						$filter_make  = (isset($_GET["make"]) && !empty($_GET["make"])) ? strtolower(urldecode($_GET["make"])) : "";
					    $filter_model = (isset($_GET["model"]) && !empty($_GET["model"])) ? strtolower(urldecode($_GET["model"])) : "";
					    $filter_year  = (isset($_GET["yr"]) && !empty($_GET["yr"])) ? strtolower(urldecode($_GET["yr"])) : "";
					    $filter_trim  = (isset($_GET["trim"]) && !empty($_GET["trim"])) ? strtolower(urldecode($_GET["trim"])) : "";
					}

				}


	            ?>

				<div class="car-filter <?php echo implode(" ",$class); ?>" data-shop="<?php echo esc_url($shop_link); ?>">

					<?php if (!empty($description)): ?>
						<div class="car-filter-description">
							<?php echo html_entity_decode($description); ?>
						</div>
					<?php endif ?>

					<form name="et-car-filter" class="et-car-filter" method="POST">
						<div>

							<?php if ($use_attrs == "true" && !empty($atts)): ?>


								<?php if ($cat): ?>

									<?php $categories = enovathemes_addons_categories(); ?>

									<?php if ($categories): ?>

										<div class="category filter-holder">
											<select name="category">
												<option class="default" value=""><?php echo esc_html__( 'Category', 'enovathemes-addons' ); ?></option>
												<?php enovathemes_addons_list_taxonomy_hierarchy_no_instance( $categories); ?>
											</select>
											<span class="alert error"><?php echo esc_html__('Choose category', 'enovathemes-addons'); ?></span>
										</div>

									<?php endif ?>

								<?php endif ?>


								<?php $counter = 0; ?>

								<?php foreach ($attibutes_filter as $attibute): ?>

									<div class="<?php echo esc_attr($attibute['name']); ?> filter-holder">
										<select name="<?php echo esc_attr($attibute['name']); ?>">
											<option class="default" value=""><?php echo esc_html($attibute['label']); ?></option>

											<?php if ($hierarchy == "true"): ?>
												<?php if ($counter == 0 && $categories == false): ?>
													<?php if ($attibute['terms']): ?>
														<?php foreach ($attibute['terms'] as $term_id => $term_name): ?>
															<option value="<?php echo $term_name; ?>" data-val="<?php echo $term_id; ?>"><?php echo esc_html($term_name); ?></option>
														<?php endforeach ?>
													<?php endif ?>
												<?php endif ?>
											<?php else: ?>
												<?php if ($attibute['terms']): ?>
													<?php foreach ($attibute['terms'] as $term_id => $term_name): ?>
														<option value="<?php echo $term_name; ?>" data-val="<?php echo $term_id; ?>"><?php echo esc_html($term_name); ?></option>
													<?php endforeach ?>
												<?php endif ?>
											<?php endif ?>

										</select>
										<span class="alert error"><?php echo esc_html__('Choose', 'enovathemes-addons').' '.$attibute['label']; ?></span>
									</div>

									<?php $counter += 1;  ?>

								<?php endforeach ?>

							<?php else: ?>
								<div class="make filter-holder">
									<select name="make">
										<option <?php echo ((empty($filter_make)) ? 'selected="selected"' : ''); ?> class="default" value=""><?php echo esc_html__('Make', 'enovathemes-addons'); ?></option>
										<?php if ($makes): ?>
											<?php foreach ($makes as $term): ?>
												<option value="<?php echo $term->term_id; ?>" <?php echo ((strtolower($term->name) == $filter_make) ? 'selected="selected"' : ''); ?>><?php echo $term->name; ?></option>
											<?php endforeach ?>
										<?php endif ?>
									</select>
									<span class="alert error"><?php echo esc_html__('Choose make', 'enovathemes-addons'); ?></span>
								</div>
								<div class="model filter-holder">
									<select name="model">
										<option class="default" value=""><?php echo esc_html__('Model', 'enovathemes-addons'); ?></option>
									</select>
									<span class="alert error"><?php echo esc_html__('Choose model', 'enovathemes-addons'); ?></span>
								</div>
								<div class="year filter-holder">
									<select name="year">
										<option class="default" value=""><?php echo esc_html__('Year', 'enovathemes-addons'); ?></option>
									</select>
									<span class="alert error"><?php echo esc_html__('Choose year', 'enovathemes-addons'); ?></span>
								</div>
								<div class="trim filter-holder">
									<select name="trim">
										<option class="default" value=""><?php echo esc_html__('Trim', 'enovathemes-addons'); ?></option>
									</select>
									<span class="alert error"><?php echo esc_html__('Choose trim', 'enovathemes-addons'); ?></span>
								</div>
							<?php endif ?>
							<?php if ($vin == "true"): ?>
								<div class="vin-label">
									<span class="vertical-vin-text vin-text"><?php echo esc_html__('Or search by VIN', 'enovathemes-addons'); ?></span>
									<span class="horizontal-vin-text vin-text"><?php echo esc_html__('Or', 'enovathemes-addons'); ?></span>
								</div>
								<div class="vin filter-holder">
									<input type="text" name="vin" placeholder="<?php echo esc_html__('Enter VIN', 'enovathemes-addons'); ?>" value="" />
									<span class="alert error"><?php echo esc_html__('Invalid or Unknown VIN', 'enovathemes-addons'); ?></span>
									<span class="alert example note"><?php echo esc_html__('Example: 1NXBR32E85Z505904', 'enovathemes-addons'); ?></span>
								</div>
							<?php endif ?>
							<div><input type="submit" class="car-filter-button" value="<?php echo esc_html__("Search","enovathemes-addons"); ?>" name="submit"></div>
						</div>

		            </form>
        		</div>

        		<?php if ($use_attrs == "true" && !empty($atts)): ?>
        			<div class="atts-holder"><span class="default"><?php  echo esc_html__("Results for: ","enovathemes-addons"); ?></span></div>
				<?php else: ?>
					<?php if (!empty($filter_make)): ?>
						<div class="atts-holder">
							<span class="default"><?php  echo esc_html__("Results for: ","enovathemes-addons"); ?></span>
							<?php if (!empty($filter_make)): ?>
								<?php
									$filter_make = get_term_by('id',$filter_make,'product-make');
									$filter_make = $filter_make->name;
								?>
								<span><?php  echo esc_html($filter_make); ?></span>
							<?php endif; ?>
							<?php if (!empty($filter_model)): ?>
								<?php
									$filter_model = get_term_by('id',$filter_model,'product-model');
									$filter_model = $filter_model->name;
								?>
								<span><?php  echo esc_html($filter_model); ?></span>
							<?php endif; ?>
							<?php if (!empty($filter_trim)): ?>
								<?php
									$filter_trim = get_term_by('id',$filter_trim,'product-trim');
									$filter_trim = $filter_trim->name;
								?>
								<span><?php  echo esc_html($filter_trim); ?></span>
							<?php endif; ?>
							<?php if (!empty($filter_year)): ?>
								<span><?php  echo esc_html($filter_year); ?></span>
							<?php endif; ?>
						</div>
					<?php endif; ?>
				<?php endif ?>

			<?php echo $after_widget;
		}

	 	public function form( $instance ) {

	 		$defaults = array(
	 			'title'              => esc_html__('Car filter', 'enovathemes-addons'),
	 			'type'               => 'vertical',
	 			'vin'                => 'false',
	 			'use_attrs'          => 'false',
	 			'hierarchy'          => 'false',
	 			'atts'               => '',
	 			'depth'              => 'trim',
	 			'description'        => esc_html__('Car parts for any car', 'enovathemes-addons'),
	 			'description_back'   => '#ffc600',
				'filter_back'        => '#ffd800',
				'filter_color'       => '#000000',
				'button_back'        => '#d52b27',
				'button_back_hover'  => '#000000',
				'button_color'       => '#ffffff',
				'button_color_hover' => '#ffffff',
	 		);

	 		$instance = wp_parse_args((array) $instance, $defaults);

			?>

			<div id="<?php echo esc_attr($this->get_field_id( 'widget_id' )); ?>" class="widget-car-filter">

				<p>
					<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo esc_html__( 'Title:', 'enovathemes-addons' ); ?></label>
					<input class="widefat <?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
				</p>

				<p>
					<input class="checkbox use-attrs" type="checkbox" <?php checked($instance['use_attrs'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('use_attrs'); ?>" name="<?php echo $this->get_field_name('use_attrs'); ?>" />
					<label for="<?php echo $this->get_field_id('use_attrs'); ?>"><?php echo esc_html__( 'Use WooCommerce global attributes for filter', 'enovathemes-addons' ); ?></label>
				</p>

				<div class="atts-on sortable-droppable-attributes">

					<p>
						<input class="checkbox use-attrs" type="checkbox" <?php checked($instance['hierarchy'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('hierarchy'); ?>" name="<?php echo $this->get_field_name('hierarchy'); ?>" />
						<label for="<?php echo $this->get_field_id('hierarchy'); ?>"><?php echo esc_html__( 'Use hierarchy?', 'enovathemes-addons' ); ?></label>
						<p class="description"><?php echo esc_html__( 'Hierarchical filter attributes have a relationship between each other from left to right. Example: Make > Model > Year > Trim', 'enovathemes-addons' ); ?></p>
					</p>

					<?php $attibutes  = enovathemes_addons_build_filter_attributes(); ?>

					<?php if ($attibutes): ?>
						<h4><?php echo esc_html__( 'Available attributes', 'enovathemes-addons' ); ?></h4>
						<ul class="draggable">
							<li data-attribute="cat,<?php echo esc_html__( 'Product category', 'enovathemes-addons' ); ?>" class="draggable-item">
								<?php echo esc_html__( 'Product category', 'enovathemes-addons' ); ?>
								<span class="remove" title="<?php echo esc_html__( 'Remove category', 'enovathemes-addons' ); ?>"></span>
							</li>
							<?php foreach ($attibutes as $attibute => $data): ?>
								<li data-attribute="<?php echo esc_attr($attibute.','.$data['label']); ?>" class="draggable-item">
									<?php echo esc_html($data['label']); ?>
									<span class="remove" title="<?php echo esc_html__( 'Remove attribute', 'enovathemes-addons' ); ?>"></span>
								</li>
							<?php endforeach ?>
						</ul>
						<h4><?php echo esc_html__( 'Drop here filter attributes', 'enovathemes-addons' ); ?></h4>
						<ul class="sortable"></ul>
					<?php endif ?>

					<input class="atts" type="hidden" id="<?php echo $this->get_field_id('atts'); ?>" name="<?php echo $this->get_field_name('atts'); ?>" value="<?php echo esc_attr( $instance['atts'] ); ?>" />

				</div>

				<p>
					<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php echo esc_html__( 'Type:', 'enovathemes-addons' ); ?></label>
					<select class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" >
	                	<option value="horizontal" <?php selected( $instance['type'], 'horizontal' ); ?>><?php echo esc_html__('horizontal', 'enovathemes-addons'); ?></option>
	                	<option value="vertical" <?php selected( $instance['type'], 'vertical' ); ?>><?php echo esc_html__('vertical', 'enovathemes-addons'); ?></option>
					</select>
				</p>

				<p class="atts-off">
					<label for="<?php echo $this->get_field_id( 'depth' ); ?>"><?php echo esc_html__( 'Filter depth (Filtering level of details):', 'enovathemes-addons' ); ?></label>
					<select class="widefat" id="<?php echo $this->get_field_id( 'depth' ); ?>" name="<?php echo $this->get_field_name( 'depth' ); ?>" >
	                	<option value="trim" <?php selected( $instance['depth'], 'trim' ); ?>><?php echo esc_html__('Make / Model / Year / Trim', 'enovathemes-addons'); ?></option>
	                	<option value="model" <?php selected( $instance['depth'], 'model' ); ?>><?php echo esc_html__('Make / Model', 'enovathemes-addons'); ?></option>
	                	<option value="make" <?php selected( $instance['depth'], 'make' ); ?>><?php echo esc_html__('Make', 'enovathemes-addons'); ?></option>
					</select>
				</p>

				<p class="atts-off">
					<input class="checkbox" type="checkbox" <?php checked($instance['vin'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('vin'); ?>" name="<?php echo $this->get_field_name('vin'); ?>" />
					<label for="<?php echo $this->get_field_id('vin'); ?>"><?php echo esc_html__( 'Enable search by VIN', 'enovathemes-addons' ); ?></label>
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php echo esc_html__( 'Description:', 'enovathemes-addons' ); ?></label>
					<textarea class="widefat" name="<?php echo $this->get_field_name( 'description' ); ?>"><?php echo $instance['description']; ?></textarea>
				</p>

				<h3><?php echo esc_html__( 'Styling', 'enovathemes-addons' ); ?></h3><hr>

				<p>
					<label for="<?php echo $this->get_field_id( 'description_back' ); ?>"><?php echo esc_html__( 'Description background color:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'description_back' ); ?>" name="<?php echo $this->get_field_name( 'description_back' ); ?>" type="text" value="<?php echo esc_attr( $instance['description_back'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'filter_back' ); ?>"><?php echo esc_html__( 'Filter background color:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'filter_back' ); ?>" name="<?php echo $this->get_field_name( 'filter_back' ); ?>" type="text" value="<?php echo esc_attr( $instance['filter_back'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'filter_color' ); ?>"><?php echo esc_html__( 'Filter color:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'filter_color' ); ?>" name="<?php echo $this->get_field_name( 'filter_color' ); ?>" type="text" value="<?php echo esc_attr( $instance['filter_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'button_back' ); ?>"><?php echo esc_html__( 'Button background color:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'button_back' ); ?>" name="<?php echo $this->get_field_name( 'button_back' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_back'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'button_color' ); ?>"><?php echo esc_html__( 'Button color:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'button_color' ); ?>" name="<?php echo $this->get_field_name( 'button_color' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'button_back_hover' ); ?>"><?php echo esc_html__( 'Button background color hover:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'button_back_hover' ); ?>" name="<?php echo $this->get_field_name( 'button_back_hover' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_back_hover'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'button_color_hover' ); ?>"><?php echo esc_html__( 'Button color hover:', 'enovathemes-addons' ); ?></label>
					<input class="widefat et-color-picker" id="<?php echo $this->get_field_id( 'button_color_hover' ); ?>" name="<?php echo $this->get_field_name( 'button_color_hover' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_color_hover'] ); ?>" />
				</p>

			</div>

			<?php
		}

		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['title']              = strip_tags( $new_instance['title'] );
			$instance['type']               = esc_attr($new_instance['type']);
			$instance['vin']                = esc_attr($new_instance['vin']);
			$instance['use_attrs']          = esc_attr($new_instance['use_attrs']);
			$instance['hierarchy']          = esc_attr($new_instance['hierarchy']);
			$instance['atts']               = esc_attr($new_instance['atts']);
			$instance['depth']              = esc_attr($new_instance['depth']);
			$instance['description']        = $new_instance['description'];
			$instance['description_back']   = esc_attr($new_instance['description_back']);
			$instance['filter_back']        = esc_attr($new_instance['filter_back']);
			$instance['filter_color']       = esc_attr($new_instance['filter_color']);
			$instance['button_back']        = esc_attr($new_instance['button_back']);
			$instance['button_back_hover']  = esc_attr($new_instance['button_back_hover']);
			$instance['button_color']       = esc_attr($new_instance['button_color']);
			$instance['button_color_hover'] = esc_attr($new_instance['button_color_hover']);
			return $instance;
		}

	}
?>
