<?php

defined( 'ABSPATH' ) || exit;

add_action('widgets_init', 'register_mailchimp_widget');
function register_mailchimp_widget(){
	register_widget( 'Enovathemes_Addons_WP_Widget_Mailchimp' );
}

function mailchimp_curl_connect( $url, $request_type, $api_key, $data = array() ) {
    if( $request_type == 'GET' )
        $url .= '?' . http_build_query($data);
 
    $mch = curl_init();
    $headers = array(
        'Content-Type: application/json',
        'Authorization: Basic '.base64_encode( 'user:'. $api_key )
    );
    curl_setopt($mch, CURLOPT_URL, $url );
    curl_setopt($mch, CURLOPT_HTTPHEADER, $headers);
    //curl_setopt($mch, CURLOPT_USERAGENT, 'PHP-MCAPI/2.0');
    curl_setopt($mch, CURLOPT_RETURNTRANSFER, true); // do not echo the result, write it into variable
    curl_setopt($mch, CURLOPT_CUSTOMREQUEST, $request_type); // according to MailChimp API: POST/GET/PATCH/PUT/DELETE
    curl_setopt($mch, CURLOPT_TIMEOUT, 10);
    curl_setopt($mch, CURLOPT_SSL_VERIFYPEER, false); // certificate verification for TLS/SSL connection
 
    if( $request_type != 'GET' ) {
        curl_setopt($mch, CURLOPT_POST, true);
        curl_setopt($mch, CURLOPT_POSTFIELDS, json_encode($data) ); // send data in json
    }
 
    return curl_exec($mch);
}

function mailchimp_subscriber_status( $email, $status, $list_id, $api_key, $merge_fields = array('FNAME' => '','LNAME' => '','ADDRESS' => '','PHONE' => '') ){

    $data = array(
        'apikey'        => $api_key,
        'email_address' => $email,
        'status'        => $status,
        'merge_fields'  => $merge_fields
    );
    $mch_api = curl_init(); // initialize cURL connection
 
    curl_setopt($mch_api, CURLOPT_URL, 'https://' . substr($api_key,strpos($api_key,'-')+1) . '.api.mailchimp.com/3.0/lists/' . $list_id . '/members/' . md5(strtolower($data['email_address'])));
    curl_setopt($mch_api, CURLOPT_HTTPHEADER, array('Content-Type: application/json', 'Authorization: Basic '.base64_encode( 'user:'.$api_key )));
    curl_setopt($mch_api, CURLOPT_USERAGENT, 'PHP-MCAPI/2.0');
    curl_setopt($mch_api, CURLOPT_RETURNTRANSFER, true); // return the API response
    curl_setopt($mch_api, CURLOPT_CUSTOMREQUEST, 'PUT'); // method PUT
    curl_setopt($mch_api, CURLOPT_TIMEOUT, 10);
    curl_setopt($mch_api, CURLOPT_POST, true);
    curl_setopt($mch_api, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($mch_api, CURLOPT_POSTFIELDS, json_encode($data) ); // send data in json
 
    $result = curl_exec($mch_api);
    return $result;
}

function mailchimp_list() {

    global $mobimax_enovathemes;
    $mailchimp_api_key = (isset($mobimax_enovathemes['mailchimp-api-key']) && !empty($mobimax_enovathemes['mailchimp-api-key'])) ? esc_attr($mobimax_enovathemes['mailchimp-api-key']): "";

    $api_key = $mailchimp_api_key;
    $transient_prefix = $api_key;

    if (empty($api_key)) {
        return new WP_Error( 'no_api_key', esc_html__( 'No Mailchimp API key is found. Go to theme options >> general >> Mailchimp API key', 'enovathemes-addons' ) );
    }

    $url = 'https://' . substr($api_key,strpos($api_key,'-')+1) . '.api.mailchimp.com/3.0/lists/';

    if ( false === ( $mailchimp_list = get_transient( 'mailchimp-' . $transient_prefix . '-enovathemes' ) ) ) {

        $data = array(
            'fields' => 'lists',
            'count' => 'all',
        );
         
        $result = json_decode( mailchimp_curl_connect( $url, 'GET', $api_key, $data) );
       
        if (! $result ) {
            return new WP_Error( 'bad_json', esc_html__( 'Mailchimp has returned invalid data.', 'enovathemes-addons' ) );
        }

        if ( !empty( $result->lists ) ) {
            foreach( $result->lists as $list ){
                $mailchimp_list[] = array(
                    'id'      => $list->id,
                    'name'    => $list->name,
                );
            }
        } elseif(is_int( $result->status)) {
            return '<strong>' . $result->title . ':</strong> ' . $result->detail;
        } else {
            return new WP_Error( 'bad_json_2', esc_html__( 'Mailchimp has returned invalid data.', 'enovathemes-addons' ) );
        }

        // do not set an empty transient - should help catch private or empty accounts.
        if ( ! empty( $mailchimp_list ) ) {
            $mailchimp_list = base64_encode( serialize( $mailchimp_list ) );
            set_transient( 'mailchimp-' . $transient_prefix . '-enovathemes', $mailchimp_list, apply_filters( 'null_mailchimp_cache_time', WEEK_IN_SECONDS * 2 ) );
        }
    }

    if ( ! empty( $mailchimp_list ) ) {

        return unserialize( base64_decode( $mailchimp_list ) );

    } else {

        return new WP_Error( 'no_list', esc_html__( 'Mailchimp did not return any list.', 'enovathemes-addons' ) );

    }
}

function mailchimp_subscribe(){

    global $post, $mobimax_enovathemes;

    if ( ! isset( $_POST['et_mailchimp_nonce'] ) || !wp_verify_nonce( $_POST['et_mailchimp_nonce'], 'et_mailchimp_action' )) {
       echo esc_html__("Sorry, your nonce did not verify.", "enovathemes-addons");
       exit;
    } else {

        $email   = filter_var(trim($_POST["email"]), FILTER_SANITIZE_EMAIL);
        $fname   = strip_tags(trim($_POST["fname"]));
        $lname   = strip_tags(trim($_POST["lname"]));
        $phone   = strip_tags(trim($_POST["phone"]));
        $list    = strip_tags(trim($_POST["list"]));

        $list_id = $list;
        $api_key = (isset($mobimax_enovathemes['mailchimp-api-key']) && !empty($mobimax_enovathemes['mailchimp-api-key'])) ? esc_attr($mobimax_enovathemes['mailchimp-api-key']): "";
        $result  = json_decode( mailchimp_subscriber_status($email, 'subscribed', $list_id, $api_key, array('FNAME' => $fname,'LNAME' => $lname,'PHONE' => $phone) ) );

        if( $result->status == 400 ){
            foreach( $result->errors as $error ) {
                echo '<p>Error: ' . $error->message . '</p>';
            }
        } elseif( $result->status == 'subscribed' ){
            echo 'Thank you, ' . $result->merge_fields->FNAME . '. You have subscribed successfully';
        }
        
        die;
    }
}

add_action('admin_post_nopriv_et_mailchimp', 'mailchimp_subscribe');
add_action('admin_post_et_mailchimp', 'mailchimp_subscribe');

class  Enovathemes_Addons_WP_Widget_Mailchimp extends WP_Widget {

	public function __construct() {
		parent::__construct(
			'mailchimp',
			esc_html__('* Mailchimp', 'enovathemes-addons'),
			array( 'description' => esc_html__('Mailchimp form', 'enovathemes-addons'))
		);
	}

	public function widget( $args, $instance ) {

		wp_enqueue_script('widget-mailchimp');

		extract($args);

		$output = "";

		$title         = apply_filters( 'widget_title', $instance['title'] );
		$description   = $instance['description'] ? esc_attr($instance['description']) : '';
		$first_name    = $instance['first_name'] ? $instance['first_name'] : 'false';
		$last_name     = $instance['last_name'] ? $instance['last_name'] : 'false';
		$phone         = $instance['phone'] ? $instance['phone'] : 'false';

		$required_first_name = $instance['required_first_name'] ? $instance['required_first_name'] : 'false';
		$required_last_name  = $instance['required_last_name'] ? $instance['required_last_name'] : 'false';
		$required_phone      = $instance['required_phone'] ? $instance['required_phone'] : 'false';

		$required_first_name = ($required_first_name == "true") ? 'data-required="true"' :  'data-required="false"'; 
		$required_last_name = ($required_last_name == "true") ? 'data-required="true"' :  'data-required="false"'; 
		$required_phone = ($required_phone == "true") ? 'data-required="true"' :  'data-required="false"'; 


		$list = $instance['list'] ? $instance['list'] : '';

		$output .= $before_widget;
		$output .='<div class="mailchimp-form">';
			if ( ! empty( $title ) ){$output .= $before_title . $title . $after_title;}
			if (!empty($description)) {
				$output .= '<p class="mailchimp-description">'.$description.'</p>';
			}
			$output .='<form class="et-mailchimp-form" name="et-mailchimp-form" action="'.esc_url( admin_url('admin-post.php') ).'" method="POST">';

				if ($first_name == "true") {
					$output .='<div>';
						$output .='<input '.$required_first_name.' class="field" type="text" value="" name="fname" placeholder="'.esc_html__("First name", 'enovathemes-addons').'">';
						$output .='<span class="alert warning">'.esc_html__('Please enter your First name', 'enovathemes-addons').'</span>';
					$output .='</div>';
				}

				if ($last_name == "true") {
					$output .='<div>';
						$output .='<input '.$required_last_name.' class="field" type="text" value="" name="lname" placeholder="'.esc_html__("Last name", 'enovathemes-addons').'">';
						$output .='<span class="alert warning">'.esc_html__('Please enter your Last name', 'enovathemes-addons').'</span>';
					$output .='</div>';
				}

				if ($phone == "true") {
					$output .='<div>';
						$output .='<input '.$required_phone.' class="field" type="text" value="" name="phone" placeholder="'.esc_html__("Phone number", 'enovathemes-addons').'">';
						$output .='<span class="alert warning">'.esc_html__('Please enter your Phone number', 'enovathemes-addons').'</span>';
					$output .= '</div>';
				}

				$output .='<div>';
					$output .='<input type="text" value="" class="field" name="email" placeholder="'.esc_html__("Email", 'enovathemes-addons').'">';
					$output .='<span class="alert warning">'.esc_html__('Invalid or empty email', 'enovathemes-addons').'</span>';
				$output .= '</div>';
				
				$output .='<input type="hidden" value="'.$list.'" name="list">';
				$output .='<input type="hidden" name="action" value="et_mailchimp" />';
				$output .='<div class="send-div">';
			    	$output .='<input type="submit" class="button" value="'.esc_html__('Subscribe', 'enovathemes-addons').'" name="subscribe">';
					$output .='<div class="sending"></div>';
				$output .='</div>';
			    $output .='<div class="et-mailchimp-success alert final success">'.esc_html__('You have successfully subscribed to the newsletter.', 'enovathemes-addons').'</div>';
		        $output .='<div class="et-mailchimp-error alert final error">'.esc_html__('Something went wrong. Your subscription failed.', 'enovathemes-addons').'</div>';
		        $output .= wp_nonce_field( "et_mailchimp_action", "et_mailchimp_nonce", false, false );

			$output .='</form>';
		$output .='</div>';
		$output .= $after_widget;
		echo $output;
	}

 	public function form( $instance ) {

		$defaults = array(
 			'title'       => esc_html__('Subscribe', 'enovathemes-addons'),
 			'description' => '',
 			'list'       => '',
 			'first_name'  => 'false',
 			'last_name'   => 'false',
 			'phone'       => 'false',
 			'required_first_name'  => 'false',
 			'required_last_name'   => 'false',
 			'required_phone'       => 'false',
 		);

 		$instance = wp_parse_args((array) $instance, $defaults);

 		$list_array = mailchimp_list();

 		?>


			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo esc_html__( 'Title:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>" />
			</p>

			<?php if ( is_wp_error( $list_array ) ): ?>
				<p><?php echo wp_kses_post( $list_array->get_error_message() ); ?></p>
			<?php else: ?>
				<p>
					<label for="<?php echo $this->get_field_id( 'list' ); ?>"><?php echo esc_html__( 'List:', 'enovathemes-addons' ); ?></label> 
					<select class="widefat" id="<?php echo $this->get_field_id( 'list' ); ?>" name="<?php echo $this->get_field_name( 'list' ); ?>" >
					<?php foreach ( $list_array as $list ) { ?>
						<option value="<?php echo $list['id']; ?>" <?php selected( $instance['list'], $list['id'] ); ?>><?php echo $list['name']; ?></option>
					<?php } ?>
					</select>
				</p>
			<?php endif; ?>

			<p>
				<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php echo esc_html__( 'Description:', 'enovathemes-addons' ); ?></label> 
				<textarea class="widefat" id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" type="text"><?php echo $instance['description']; ?></textarea>
			</p>

			<p class="et-clearfix label-right">
				<label for="<?php echo $this->get_field_id('first_name'); ?>"><?php echo esc_html__( 'Show first name field', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['first_name'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('first_name'); ?>" name="<?php echo $this->get_field_name('first_name'); ?>" /> 
				</label>
				<label for="<?php echo $this->get_field_id('required_first_name'); ?>"><?php echo esc_html__( 'Required?', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['required_first_name'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('required_first_name'); ?>" name="<?php echo $this->get_field_name('required_first_name'); ?>" /> 
				</label>
			</p>

			<p class="et-clearfix label-right">
				<label for="<?php echo $this->get_field_id('last_name'); ?>"><?php echo esc_html__( 'Show last name field', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['last_name'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('last_name'); ?>" name="<?php echo $this->get_field_name('last_name'); ?>" /> 
				</label>
				<label for="<?php echo $this->get_field_id('required_last_name'); ?>"><?php echo esc_html__( 'Required?', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['required_last_name'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('required_last_name'); ?>" name="<?php echo $this->get_field_name('required_last_name'); ?>" /> 
				</label>
			</p>

			<p class="et-clearfix label-right">
				<label for="<?php echo $this->get_field_id('phone'); ?>"><?php echo esc_html__( 'Show phone field', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['phone'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('phone'); ?>" name="<?php echo $this->get_field_name('phone'); ?>" /> 
				</label>
				<label for="<?php echo $this->get_field_id('required_phone'); ?>"><?php echo esc_html__( 'Required?', 'enovathemes-addons' ); ?>
					<input class="checkbox" type="checkbox" <?php checked($instance['required_phone'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('required_phone'); ?>" name="<?php echo $this->get_field_name('required_phone'); ?>" /> 
				</label>
			</p>

		
	<?php }

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title']       = strip_tags( $new_instance['title'] );
		$instance['first_name']  = strip_tags( $new_instance['first_name'] );
		$instance['last_name']   = strip_tags( $new_instance['last_name'] );
		$instance['description'] = strip_tags( $new_instance['description']);
		$instance['phone']       = strip_tags( $new_instance['phone']);
		$instance['list']        = strip_tags( $new_instance['list']);
		$instance['required_first_name']  = strip_tags( $new_instance['required_first_name'] );
		$instance['required_last_name']   = strip_tags( $new_instance['required_last_name'] );
		$instance['required_phone']       = strip_tags( $new_instance['required_phone']);
		return $instance;
	}
}

?>