<?php 
	
	defined( 'ABSPATH' ) || exit;
	
	add_action('widgets_init', 'enovathemes_addons_register_vin_decoder_widget');
	function enovathemes_addons_register_vin_decoder_widget(){
		register_widget( 'Enovathemes_Addons_WP_Widget_Vin_Decoder' );
	} 

	class Enovathemes_Addons_WP_Widget_Vin_Decoder extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'vin_decoder_widget',
				esc_html__('* Vin decoder', 'enovathemes-addons'),
				array( 'description' => esc_html__('Vehicle Vin decoder', 'enovathemes-addons'))
			);
		}

		public function widget( $args, $instance) {

			wp_enqueue_script('widget-vin-decoder');

			extract($args);

			$title            = apply_filters( 'widget_title', $instance['title'] );
			$search_by_vin    = isset($instance['search_by_vin']) ? esc_attr($instance['search_by_vin']) : 'false';
			$depth            = isset($instance['depth']) ? esc_attr($instance['depth']) : 'trim';
			$title_color      = isset($instance['title_color']) ? esc_attr($instance['title_color']) : '#ffc600';
			$vin_back         = isset($instance['vin_back']) ? esc_attr($instance['vin_back']) : '#000000';
			$vin_color        = isset($instance['vin_color']) ? esc_attr($instance['vin_color']) : '#000000';

			$button_back       = isset($instance['button_back']) ? esc_attr($instance['button_back']) : '#d52b27';
			$button_back_hover = isset($instance['button_back_hover']) ? esc_attr($instance['button_back_hover']) : '#000000';

			$button_color       = isset($instance['button_color']) ? esc_attr($instance['button_color']) : '#ffffff';
			$button_color_hover = isset($instance['button_color_hover']) ? esc_attr($instance['button_color_hover']) : '#ffffff';

			wp_enqueue_style('widget-vin-decoder-styles');
				
			$dynamic_css = "";
			$id          = $args['widget_id'];

			if (!empty($title_color)) {
				$dynamic_css .='#'.$id.' .widget_title{
					color: '.$title_color.';
				}';
			}

			if (!empty($vin_back)) {
				$dynamic_css .='#'.$id.' .vin-decoder{
					background-color: '.$vin_back.';
					box-shadow:inset 0 0 0 1px '.mobimax_enovathemes_hex_to_rgb_shade($vin_back,10).';
				}';
				$dynamic_css .='#'.$id.' .widget_title{
					background-color: '.mobimax_enovathemes_hex_to_rgb_shade($vin_back,5).';
				}';
			}

			if (!empty($vin_color)) {
				$dynamic_css .='#'.$id.' .vin-decoder{
					color: '.$vin_color.';
				}';
			}
			
			if (!empty($button_back)) {
				$dynamic_css .='#'.$id.' .vin-decoder-button{
					background-color: '.$button_back.';
				}';
			}

			if (!empty($button_back_hover)) {
				$dynamic_css .='#'.$id.' .vin-decoder-button:hover{
					background-color: '.$button_back_hover.';
				}';
			}

			if (!empty($button_color)) {
				$dynamic_css .='#'.$id.' .vin-decoder-button{
					color: '.$button_color.';
				}';
			}

			if (!empty($button_color_hover)) {
				$dynamic_css .='#'.$id.' .vin-decoder-button:hover{
					color: '.$button_color_hover.';
				}';
			}

			$dynamic_css = mobimax_enovathemes_minify_css($dynamic_css);
			wp_add_inline_style( 'widget-vin-decoder-styles', $dynamic_css );

			echo $before_widget;

			    $class = array();

			    if ($search_by_vin == "true") {
			    	$class[] = 'search-by-vin-'.$search_by_vin;
			    }

			    $class[] = 'depth-'.$depth;

			    $shop_link = (function_exists('wc_get_page_id')) ? get_permalink( wc_get_page_id( 'shop' ) ) : '';

			    if ('' === get_option( 'permalink_structure' )) {
			    	$shop_link = get_home_url().'?post_type=product';
			    }

	            ?>

				<div class="vin-decoder <?php echo implode(" ",$class); ?>" data-shop="<?php echo esc_url($shop_link); ?>">

					<?php if ( ! empty( $title ) ){
						echo $before_title . $title . $after_title;
					} ?>

					<form name="et-vin-decoder" class="et-vin-decoder" method="POST">
						<div>
							<input type="text" name="vin" placeholder="<?php echo esc_html__('Enter VIN', 'enovathemes-addons'); ?>" value="" />
							<span class="alert error"><?php echo esc_html__('Invalid or Unknown VIN', 'enovathemes-addons'); ?></span>
							<span class="alert example note"><?php echo esc_html__('Example: 1NXBR32E85Z505904', 'enovathemes-addons'); ?></span>
							<div><input type="submit" class="vin-decoder-button" value="<?php echo esc_html__("Go","enovathemes-addons"); ?>" name="submit"></div>
						</div>
		            </form>
        		</div>

			<?php echo $after_widget;
		}

	 	public function form( $instance ) {

	 		$defaults = array(
	 			'title'              => esc_html__('Vin decoder', 'enovathemes-addons'),
	 			'search_by_vin'      => 'false',
	 			'depth'              => 'trim',
	 			'title_color'        => '#000000',
				'vin_back'           => '#ffd800',
				'vin_color'          => '#000000',
				'button_back'        => '#d52b27',
				'button_back_hover'  => '#000000',
				'button_color'       => '#ffffff',
				'button_color_hover' => '#ffffff',
	 		);

	 		$instance = wp_parse_args((array) $instance, $defaults);

	 		$title = $instance['title'];

			?>

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo esc_html__( 'Title:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" class="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
			</p>

			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['search_by_vin'], 'true'); ?> value="true" id="<?php echo $this->get_field_id('search_by_vin'); ?>" name="<?php echo $this->get_field_name('search_by_vin'); ?>" /> 
				<label for="<?php echo $this->get_field_id('search_by_vin'); ?>"><?php echo esc_html__( 'Enable search by VIN', 'enovathemes-addons' ); ?></label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'depth' ); ?>"><?php echo esc_html__( 'Search level of details:', 'enovathemes-addons' ); ?></label> 
				<select class="widefat" id="<?php echo $this->get_field_id( 'depth' ); ?>" name="<?php echo $this->get_field_name( 'depth' ); ?>" >
                	<option value="trim" <?php selected( $instance['depth'], 'trim' ); ?>><?php echo esc_html__('Make / Model / Year / Trim', 'enovathemes-addons'); ?></option>
                	<option value="model" <?php selected( $instance['depth'], 'model' ); ?>><?php echo esc_html__('Make / Model', 'enovathemes-addons'); ?></option>
                	<option value="make" <?php selected( $instance['depth'], 'make' ); ?>><?php echo esc_html__('Make', 'enovathemes-addons'); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'title_color' ); ?>"><?php echo esc_html__( 'Title color:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'title_color' ); ?>" name="<?php echo $this->get_field_name( 'title_color' ); ?>" type="text" value="<?php echo esc_attr( $instance['title_color'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'vin_back' ); ?>"><?php echo esc_html__( 'Decoder background color:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'vin_back' ); ?>" name="<?php echo $this->get_field_name( 'vin_back' ); ?>" type="text" value="<?php echo esc_attr( $instance['vin_back'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'vin_color' ); ?>"><?php echo esc_html__( 'Decoder color:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'vin_color' ); ?>" name="<?php echo $this->get_field_name( 'vin_color' ); ?>" type="text" value="<?php echo esc_attr( $instance['vin_color'] ); ?>" />
			</p>
			
			<p>
				<label for="<?php echo $this->get_field_id( 'button_back' ); ?>"><?php echo esc_html__( 'Button background color:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'button_back' ); ?>" name="<?php echo $this->get_field_name( 'button_back' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_back'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'button_color' ); ?>"><?php echo esc_html__( 'Button color:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'button_color' ); ?>" name="<?php echo $this->get_field_name( 'button_color' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_color'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'button_back_hover' ); ?>"><?php echo esc_html__( 'Button background color hover:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'button_back_hover' ); ?>" name="<?php echo $this->get_field_name( 'button_back_hover' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_back_hover'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'button_color_hover' ); ?>"><?php echo esc_html__( 'Button color hover:', 'enovathemes-addons' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'button_color_hover' ); ?>" name="<?php echo $this->get_field_name( 'button_color_hover' ); ?>" type="text" value="<?php echo esc_attr( $instance['button_color_hover'] ); ?>" />
			</p>

			<?php
		}

		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['title']              = strip_tags( $new_instance['title'] );
			$instance['search_by_vin']      = esc_attr($new_instance['search_by_vin']);
			$instance['depth']              = esc_attr($new_instance['depth']);
			$instance['title_color']         = esc_attr($new_instance['title_color']);
			$instance['vin_back']           = esc_attr($new_instance['vin_back']);
			$instance['vin_color']          = esc_attr($new_instance['vin_color']);
			$instance['button_back']        = esc_attr($new_instance['button_back']);
			$instance['button_back_hover']  = esc_attr($new_instance['button_back_hover']);
			$instance['button_color']       = esc_attr($new_instance['button_color']);
			$instance['button_color_hover'] = esc_attr($new_instance['button_color_hover']);
			return $instance;
		}

	}
?>