<?php

defined( 'ABSPATH' ) || exit;

class Enovathemes_Addons_Widget_Layered_Nav {

	protected $defaults = array(
		'category' => '',
		'children' => false,
	);

	protected $widgets = array(
		'woocommerce_layered_nav',
	);

	function __construct() {
		add_action( 'in_widget_form', array( $this, 'add_settings' ), 10, 3 );
		add_filter( 'widget_update_callback', array( $this, 'save_settings' ), 10, 4 );
		add_filter( 'widget_display_callback', array( $this, 'frontend_settings' ), 10, 3 );
	}

	public function add_settings( $widget, $return, $instance ) {


		if ( ! $this->is_supported( $widget ) ) {
			return null;
		}

		// Make sure $instance contains at least our default values.
		$instance   = wp_parse_args( $instance, $this->defaults );

		$categories = enovathemes_addons_categories();

		?>
		<?php if ($categories): ?>
			<p>
				<label for="<?php echo esc_attr( $widget->get_field_id( 'category' ) ); ?>">
					<?php echo esc_html__( 'Show only for selected category:', 'enovathemes-addons' ); ?>
				</label>
				<select class="widefat custom-select" id="<?php echo $widget->get_field_id( 'category' ); ?>" name="<?php echo $widget->get_field_name( 'category' ); ?>" >
					<option value="" <?php selected( $instance['category'],'' ); ?>><?php echo esc_html__("- Select category -","enovathemes-addons"); ?></option>
					<?php enovathemes_addons_list_taxonomy_hierarchy( $categories, $instance); ?>
				</select>
			</p>

			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['children'], 'true'); ?> value="true" id="<?php echo $widget->get_field_id('children'); ?>" name="<?php echo $widget->get_field_name('children'); ?>" /> 
				<label for="<?php echo $widget->get_field_id('children'); ?>"><?php echo esc_html__( 'Including child categories?', 'enovathemes-addons' ); ?></label>
			</p>

		<?php endif ?>
		<?php
	}

	public function save_settings( $instance, $new_instance, $old_instance, $widget ) {
		if ( ! $this->is_supported( $widget ) ) {
			return $instance;
		}

		// Make sure $instance contains at least our default values.
		$instance = wp_parse_args( $instance, $this->defaults );

		// Now check that a value is actually present, and assign it sanitized.
		if ( isset( $new_instance['category'] ) ) {
			$instance['category'] = esc_html( $new_instance['category'] );
		}

		// Now check that a value is actually present, and assign it sanitized.
		if ( isset( $new_instance['children'] ) && $new_instance['children'] != false) {
			$instance['children'] = esc_attr( $new_instance['children'] );
		}

		return $instance;
	}

	public function frontend_settings( $instance, $widget, $args ) {
		if ( ! $this->is_supported( $widget ) ) {
			return $instance;
		}

		$instance = wp_parse_args( $instance, $this->defaults );

		if ( $instance['category'] ) {

			if ($instance['children']) {
				return (enovathemes_addons_is_or_descendant_tax($instance['category'],'product_cat')) ? $instance : false;
			} else {
				return (is_tax('product_cat',$instance['category'] )) ? $instance : false;
			}

			
		} else {
			return $instance;
		}

	}

	protected function is_supported( WP_Widget $widget ) {

		if ( in_array( $widget->id_base, $this->widgets, true ) ) {
			return true;
		} else {
			return false;
		}
	}
}

new Enovathemes_Addons_Widget_Layered_Nav();

?>