<?php
/**
 * The template for displaying product category thumbnails within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product_cat.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


$filter_make  = (isset($_GET["make"]) && !empty($_GET["make"])) ? urldecode($_GET["make"]) : "";
$filter_model = (isset($_GET["model"]) && !empty($_GET["model"])) ? urldecode($_GET["model"]) : "";
$filter_trim  = (isset($_GET["trim"]) && !empty($_GET["trim"])) ? urldecode($_GET["trim"]) : "";

$taxquery = array();
$active_category_array = array();

if (!empty($filter_make)) {
    $taxquery_make = array(
        'taxonomy' => 'product-make',
        'field'    => 'name',
        'terms'    => $filter_make,
        'operator' => 'IN'
    );
    array_push($taxquery, $taxquery_make);
}

if (!empty($filter_model)) {
    $taxquery_model = array(
        'taxonomy' => 'product-model',
        'field'    => 'name',
        'terms'    => $filter_model,
        'operator' => 'IN'
    );
    array_push($taxquery, $taxquery_model);
}

if (!empty($filter_trim)) {
    $taxquery_trim = array(
        'taxonomy' => 'product-trim',
        'field'    => 'name',
        'terms'    => $filter_trim,
        'operator' => 'IN'
    );
    array_push($taxquery, $taxquery_trim);
}

if (!empty($taxquery)) {

    $products = new WP_Query(array(
        'post_type'           => 'product',
        'post_status'         => 'publish',
        'ignore_sticky_posts' => 0,
        'posts_per_page'      => -1, 
        'tax_query'           => $taxquery
    ));

    if($products->have_posts()){
        while ($products->have_posts() ) {
            $products->the_post();

            global $post;

            $product_categories = wp_get_post_terms( $post->ID, 'product_cat');

            foreach ($product_categories as $cat) {
                array_push($active_category_array, $cat->term_id);
            }

        }

        wp_reset_postdata();
    }

    $active_category_array = array_unique($active_category_array);
}

	$active = 'true';

	if (!empty($active_category_array)) {
		if (in_array($category->term_id,$active_category_array)) {
			$active = 'true';
		} else {
			$active = 'false';
		}
	}

?>
<li id="<?php echo esc_attr($category->term_id); ?>" <?php wc_product_cat_class( '', $category ); ?> data-active="<?php echo esc_attr($active); ?>">
	<?php
	/**
	 * woocommerce_before_subcategory hook.
	 *
	 * @hooked woocommerce_template_loop_category_link_open - 10
	 */
	do_action( 'woocommerce_before_subcategory', $category );

	/**
	 * woocommerce_before_subcategory_title hook.
	 *
	 * @hooked woocommerce_subcategory_thumbnail - 10
	 */
	do_action( 'woocommerce_before_subcategory_title', $category );

	/**
	 * woocommerce_shop_loop_subcategory_title hook.
	 *
	 * @hooked woocommerce_template_loop_category_title - 10
	 */
	do_action( 'woocommerce_shop_loop_subcategory_title', $category );

	/**
	 * woocommerce_after_subcategory_title hook.
	 */
	do_action( 'woocommerce_after_subcategory_title', $category );

	/**
	 * woocommerce_after_subcategory hook.
	 *
	 * @hooked woocommerce_template_loop_category_link_close - 10
	 */
	do_action( 'woocommerce_after_subcategory', $category ); ?>
</li>
